Services
========

Service modules implement business logic for each API endpoint.

.. module:: numistalib.services

Base Services
-------------

.. automodule:: numistalib.services.base.service
   :members:
   :undoc-members:
   :show-inheritance:

Types Service
-------------

.. automodule:: numistalib.services.types.service
   :members:
   :undoc-members:
   :show-inheritance:

Catalogues Service
------------------

.. automodule:: numistalib.services.catalogues.service
   :members:
   :undoc-members:
   :show-inheritance:

Issuers Service
---------------

.. automodule:: numistalib.services.issuer.service
   :members:
   :undoc-members:
   :show-inheritance:

Issues Service
--------------

.. automodule:: numistalib.services.issues.service
   :members:
   :undoc-members:
   :show-inheritance:

Mints Service
-------------

.. automodule:: numistalib.services.mints.service
   :members:
   :undoc-members:
   :show-inheritance:

Collections Service
-------------------

.. automodule:: numistalib.services.collections.service
   :members:
   :undoc-members:
   :show-inheritance:

Image Search Service
--------------------

.. automodule:: numistalib.services.image_search.service
   :members:
   :undoc-members:
   :show-inheritance:

Literature Service
------------------

.. automodule:: numistalib.services.literature.service
   :members:
   :undoc-members:
   :show-inheritance:

Prices Service
--------------

.. automodule:: numistalib.services.prices.service
   :members:
   :undoc-members:
   :show-inheritance:

Users Service
-------------

.. automodule:: numistalib.services.users.service
   :members:
   :undoc-members:
   :show-inheritance:
